#[non_exhaustive]pub struct RelayIdentityRsaPublicKey(pub PublicKey);Expand description
Public key component of this keypair. Useful if we move the public key around, it then keeps it semantic with the name and less prone to errors.
Tuple Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.0: PublicKeyImplementations