#[non_exhaustive]pub struct RelayNtorKeypair(StaticKeypair);Expand description
[KP_ntor] Medium-term keypair for the circuit extension handshake. Rotated periodically.
Tuple Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.0: StaticKeypairImplementations
Sourceimpl RelayNtorKeypair
impl RelayNtorKeypair
Sourcepub fn public(&self) -> RelayNtorPublicKey
pub fn public(&self) -> RelayNtorPublicKey
Build the raw inner public key into the wrapper public key object.
Sourcepub fn diffie_hellman<T>(&self, pk: T) -> SharedSecret
pub fn diffie_hellman<T>(&self, pk: T) -> SharedSecret
Wrapper around the diffie_hellman() function of the underlying type. This is pretty fun because it accepts both the PK_NAME wrapper or the raw inner curve25519::PublicKey.