RelayNtorKeys

Struct RelayNtorKeys 

pub struct RelayNtorKeys {
    latest: RelayNtorKeypair,
    previous: Option<RelayNtorKeypair>,
}
The relay’s ntor key set contains both the current key and the previous one, allowing it to handle clients or relays that may be using different consensus views.

Fields

latest: RelayNtorKeypair

The latest Ntor key.

previous: Option<RelayNtorKeypair>

The previous Ntor key. First run, not previous key or if expired.

Implementations

Source

impl RelayNtorKeys

pub fn new(latest: RelayNtorKeypair) -> Self

Constructor.

pub fn with_previous(self, previous: RelayNtorKeypair) -> Self

Set the previous Ntor key.

pub fn latest(&self) -> &RelayNtorKeypair

Return the latest.

pub fn previous(&self) -> Option<&RelayNtorKeypair>

Return the previous key, if any.